@@ -6,7 +6,7 @@ use DateTime::Format::Strptime;
 use Encode;
 use Time::HiRes;
 use UNIVERSAL::require;
-use WWW::Mechanize;
+use Plagger::Mechanize;
 
 sub plugin_id {
     my $self = shift;
@@ -24,8 +24,7 @@ sub register {
 sub load {
     my ($self, $context) = @_;
 
-    $self->{mech} = WWW::Mechanize->new(cookie_jar => $self->cache->cookie_jar); # enbug???
-    $self->{mech}->agent_alias( "Windows IE 6" );
+    $self->{mech} = Plagger::Mechanize->new(cookie_jar => $self->cookie_jar);
 
     my $feed = Plagger::Feed->new;
     $feed->aggregator(sub { $self->aggregate(@_) });
@@ -129,9 +128,14 @@ sub login {
 
     my $start_url = 'http://www.frepa.livedoor.com/';
     my $res = $self->{mech}->get($start_url);
-    return 0 unless $self->{mech}->success;
+    return unless $self->{mech}->success;
 
     if ($self->{mech}->content =~ /loginside/) {
+        unless ($args{livedoor_id} && $args{password}) {
+            Plagger->context->log(error => "Error logging in using existent Cookies. Your User-Agent (" . $self->{mech}->agent . ") should strictly match with the UA used with the Cookies.");
+            return;
+        }
+
         Plagger->context->log(debug => "cookie not found. logging in");
         $self->{mech}->submit_form(
             fields => {
@@ -141,8 +145,8 @@ sub login {
             },
         );
         $self->{mech}->submit;
-        return 0 unless $self->{mech}->success;
-        return 0 if $self->{mech}->content =~ /loginside/;
+        return unless $self->{mech}->success;
+        return if $self->{mech}->content =~ /loginside/;
     }
 
     return 1;
@@ -207,6 +211,17 @@ This plugin fetches your friend blog updates from livedoor Frepa
 See L<Plagger::Plugin::CustomFeed::Mixi> for C<fetch_body>,
 C<fetch_body_interval> and C<show_icon>.
 
+Note that you don't have to supply livedoor_id and password if you set
+global cookie_jar in your configuration file and the cookie_jar
+contains a valid login session there, such as:
+
+  global:
+    user_agent:
+      cookies: /path/to/cookies.txt
+
+See L<Plagger::Cookies> for details.
+
+
 =head1 AUTHOR
 
 Kazuhiro Osawa
@@ -217,7 +232,7 @@ Tatsuhiko Miyagawa
 
 =head1 SEE ALSO
 
-L<Plagger>, L<Plagger::Plugin::CustomFeed::Mixi>, L<WWW::Mechanize>,
+L<Plagger>, L<Plagger::Plugin::CustomFeed::Mixi>, L<Plagger::Mechanize>,
 L<http://frepa.livedoor.com/>
 
 =cut
